import { EventEmitter, ElementRef, TemplateRef } from '@angular/core';
/**
 * Bootstrap modal confirmation dialog component
 */
export declare class ConfirmationDialogComponent {
    private _platformId;
    /**
     * Indication whether is dialog visible
     */
    private _visible;
    /**
     * Data that can be passed to confirmation
     */
    private _data;
    /**
     * Indication whether is code running in browser
     */
    private _isBrowser;
    /**
     * Id of confirmation dialog
     *
     * @internal
     */
    id: string;
    /**
     * Button type: default, primary, success, info, warning, danger, link
     */
    _confirmButtonType: string;
    /**
     * Button that is used for confirmation
     *
     * @internal
     */
    confirmButton: ElementRef;
    /**
     * Button that is used for cancelation
     *
     * @internal
     */
    cancelButton: ElementRef;
    /**
     * Confirmation dialog body template
     */
    template: TemplateRef<any>;
    /**
     * Text of confirmation dialog, allows html elements in text
     */
    confirmationText: string;
    /**
     * Text for cancel button
     */
    dialogCancelText: string;
    /**
     * Text for confirm button
     */
    dialogConfirmText: string;
    /**
     * Text that is displayed as title of confirmation
     */
    confirmationTitle: string;
    /**
     * Modal dialog extra css classes
     */
    dialogCss: string;
    /**
     * Button type: default, primary, success, info, warning, danger, link
     */
    set confirmButtonType(value: string);
    /**
     * Occurs when user confirmed dialog
     */
    confirmed: EventEmitter<any>;
    /**
     * Occurs when user canceled confirmation
     */
    canceled: EventEmitter<any>;
    /**
     * Gets or sets indication whether is confirmation dialog visible
     *
     * @internal
     */
    get visible(): boolean;
    set visible(visible: boolean);
    constructor(_platformId: Object);
    /**
     * Shows confirmation dialog and stores data that are passed to confirmed event
     * @param data - Data that are passed through dialog
     */
    showConfirmation(data: any): void;
    /**
     * Sets focus to one of buttons, if passed parameter is true then confirm button focus is set, otherwise cancelation button is set focus
     */
    setFocus(confirmFocus?: boolean): void;
    /**
     * Method called for confirmation
     *
     * @internal
     */
    confirm(): void;
}
//# sourceMappingURL=confirmationDialog.component.d.ts.map