import { ElementRef, OnInit, OnDestroy, EventEmitter } from '@angular/core';
import { GlobalizationService } from '@anglr/common';
import { Observable } from 'rxjs';
import * as moment from 'moment';
/**
 * Directive that is used for creating date/datetimepicker
 */
export declare class DatetimePickerDirective implements OnInit, OnDestroy {
    private _element;
    /**
     * Indication that current code is running in browser
     */
    private _isBrowser;
    /**
     * Private value used on server side
     */
    private _value;
    /**
     * Indication that value was first time set
     */
    private _firstSetValue;
    /**
     * Subscription for globalization changes
     */
    private _globalizationSubscription;
    /**
     * Subject that is used for emitting changed values
     */
    private _pickerChangedSubject;
    /**
     * Moment js format of datetimer picker
     */
    set format(value: string);
    /**
     * Moment js locale that will set format of date time
     */
    locale: string;
    /**
     * Object of other datetime picker which will be linked with this, set only on second one (containing higher value)
     */
    linkWith: DatetimePickerDirective;
    /**
     * Minimum date that is allowed to enter
     */
    set minDate(value: moment.Moment);
    /**
     * Maximum date that is allowed to enter
     */
    set maxDate(value: moment.Moment);
    /**
     * Output event that is triggered when value of picker has changed
     */
    dateChange: EventEmitter<moment.Moment>;
    /**
     * Gets observable that is trigerred when picker value changed
     */
    get pickerChanged(): Observable<moment.Moment>;
    /**
     * Gets or sets value of datetime picker, any picker supported value
     */
    get value(): any;
    set value(val: any);
    /**
     * Gets jQuery object for datetime picker
     */
    private get selector();
    /**
     * Gets object of datetime picker
     */
    private get pickerObj();
    constructor(_element: ElementRef, type: string, globalizationService: GlobalizationService, platformId: Object);
    /**
     * Initialize component
     */
    ngOnInit(): void;
    /**
     * Called when component is destroyed
     */
    ngOnDestroy(): void;
    /**
     * Toggles visibility of date time picker
     */
    toggle(): void;
    /**
     * Emits internal change of value based on mix/max date
     * @param val - Current value that is checked
     */
    private _emitIfInternalIsSame;
}
//# sourceMappingURL=datetimePicker.directive.d.ts.map