import { ElementRef, OnInit, OnDestroy } from '@angular/core';
import { Observable } from 'rxjs';
/**
 * Directive that is used for creating autocomplete (typeahead.js) on input
 */
export declare class TypeaheadDirective implements OnInit, OnDestroy {
    private _platformId;
    /**
     * Indication that current code is running in browser
     */
    private _isBrowser;
    /**
     * Currently selected value
     */
    private _value;
    /**
     * Indication that component is initialized
     */
    private _initialized;
    /**
     * Subject that is used for emitting changes
     */
    private _valueChangeSubject;
    /**
     * Subject that is used for emitting changes for model binding
     */
    private _externalValueChangeSubject;
    /**
     * Subject that is used for emitting selection of value from options
     */
    private _externalValueSelectedSubject;
    /**
     * Gets jQuery object for typeahead autocomplete
     */
    private _selector;
    /**
     * Indication that also non existing value from options will be accepted as value, it is always as string value
     */
    freeInput: boolean;
    /**
     * Maximal number of displayed items
     */
    typeaheadMaxItems: number;
    /**
     * Minimal number of characters to start search
     */
    typeaheadMinLength: number;
    /**
     * Name of displayed property as selected value
     */
    typeaheadDisplayedProperty: string | ((suggestion: any) => string) | null;
    /**
     * Name of property that is used for extracting value from object
     */
    typeaheadValueProperty: string | null;
    /**
     * Debounce time that indicates after which time of idle perform search
     */
    typeaheadDebounceTime: number;
    /**
     * Template that is used for suggestion, using handlebar syntax
     */
    typeaheadTemplate: string | null;
    /**
     * Function that is called to obtain data for search
     */
    typeaheadSource: ((query: any) => Observable<any>) | null;
    /**
     * Css class that is applied to input if no value is selected
     */
    noValueCssClass: boolean;
    /**
     * Gets or sets currently set value
     */
    get value(): any;
    set value(val: any);
    /**
     * Gets observable that emits selection of item from options
     */
    get valueSelected(): Observable<any>;
    /**
     * Gets observable that emits changes of value
     */
    get valueChanged(): Observable<any>;
    constructor(element: ElementRef, _platformId: Object);
    /**
     * Initialize component
     */
    ngOnInit(): void;
    /**
     * Called when component is destroyed
     */
    ngOnDestroy(): void;
    /**
     * Called when 'input' event occurs on input element
     * @param value - Changed value
     */
    inputChange(value: string): void;
    /**
     * Sets selected value
     * @param suggestion - Suggestion that was selected or auto completed
     */
    private _setValue;
    /**
     * Converts val from suggestion to value of directive
     * @param val - Val to be converted
     */
    private _toValue;
}
//# sourceMappingURL=typeahead.directive.d.ts.map